@@ -15,6 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-llvm_libdir = '/usr/lib64/llvm'
+llvm_libdir = '/usr/lib/llvm-3.5/lib'
 
 # ex:ts=4:et:
